@@ -1,7 +1,6 @@
 import time, os
-from scipy.ndimage.filters import maximum_filter1d
+from scipy.ndimage import maximum_filter1d, find_objects
 import torch
-import scipy.ndimage
 import numpy as np
 import tifffile
 from tqdm import trange
@@ -85,7 +84,7 @@ def _extend_centers_gpu(neighbors, centers, isneighbor, Ly, Lx, n_iter=200, devi
     dy = grads[:,0] - grads[:,1]
     dx = grads[:,2] - grads[:,3]
     del grads
-    mu_torch = np.stack((dy.cpu().squeeze(), dx.cpu().squeeze()), axis=-2)
+    mu_torch = np.stack((dy.cpu().squeeze(0), dx.cpu().squeeze(0)), axis=-2)
     return mu_torch
 
 
@@ -126,7 +125,7 @@ def masks_to_flows_gpu(masks, device=None):
     neighbors = np.stack((neighborsY, neighborsX), axis=-1)
 
     # get mask centers
-    slices = scipy.ndimage.find_objects(masks)
+    slices = find_objects(masks)
     
     centers = np.zeros((masks.max(), 2), 'int')
     for i,si in enumerate(slices):
@@ -189,7 +188,7 @@ def masks_to_flows_cpu(masks, device=None):
     mu_c = np.zeros((Ly, Lx), np.float64)
     
     nmask = masks.max()
-    slices = scipy.ndimage.find_objects(masks)
+    slices = find_objects(masks)
     dia = utils.diameters(masks)[0]
     s2 = (.15 * dia)**2
     for i,si in enumerate(slices):
@@ -578,6 +577,12 @@ def remove_bad_flow_masks(masks, flows, threshold=0.4, use_gpu=False, device=Non
         size [Ly x Lx] or [Lz x Ly x Lx]
     
     """
+    if masks.size > 10000*10000:
+        if masks.size * 20 > torch.cuda.mem_get_info()[0]:
+            dynamics_logger.warning('WARNING: image is very large, not using gpu to compute flows from masks for QC step flow_threshold')
+            dynamics_logger.info('turn off QC step with flow_threshold=0 if too slow')
+        use_gpu = False
+
     merrors, _ = metrics.flow_error(masks, flows, use_gpu, device)
     badi = 1+(merrors>threshold).nonzero()[0]
     masks[np.isin(masks, badi)] = 0
